% This is the main driver program for simulating steady-state cardiac
% energetics of the moderate LVH hearts under different work rates.
% Written by Fan Wu and Daniel Beard, Medical College of Wisconsin, 2008

clear;
setup;

global iPO2 idPsi iH_x iATP_x iADP_x iAMP_x iGTP_x iGDP_x iPI_x iNADH_x iQH2_x ...
       iOAA_x iACCOA_x iCIT_x iICIT_x iAKG_x iSCOA_x iCOASH_x iSUC_x iFUM_x ...
       iMAL_x iGLU_x iASP_x iK_x iMg_x iCO2tot_x iCred_i iATP_i iADP_i iAMP_i ...
       iPI_i iH_i iMg_i iK_i iATP_c iADP_c iPI_c iH_c iMg_c iK_c iPYR_x iPYR_i ...
       iPYR_c iCIT_i iCIT_c iAKG_i iAKG_c iSUC_i iSUC_c iMAL_i iMAL_c iASP_i ...
       iASP_c iGLU_i iGLU_c iFUM_i iFUM_c iICIT_i iICIT_c iPCr_c iAMP_c iCr_c;
     
global i_J_C1 i_J_C3 i_J_C4 i_J_F1 i_J_ANT i_J_PI1 i_J_Hle i_J_KH i_J_pdh i_J_cits ...
       i_J_acon i_J_isod i_J_akgd i_J_scoas i_J_sdh i_J_fum i_J_mdh i_J_ndk i_J_got ...
	     i_J_PI2 i_J_ATPt i_J_ADPt i_J_AMPt i_J_PYR_H i_J_GLU_H i_J_CIT_MAL i_J_SUC_MAL ... 
       i_J_AKG_MAL i_J_MAL_PI i_J_ASP_GLU i_J_PYRt i_J_CITt i_J_ICITt i_J_MALt ... 
	     i_J_AKGt i_J_SUCt i_J_FUMt i_J_GLUt i_J_ASPt i_J_CKe i_J_AKe i_J_AtC;

options = odeset('NonNegative', 1:62);

% iflag: 0 - normal; 1 - no oxygen consumption; 
%       8 - fixed PI_c; 9 - fixed ADP_c;
%       10 - no CK activity; 11 -
%       no CK and fixed PI_c; 12 - no CK and fixed ADP_c;
%       100 - constant J_AtC = x_AtC;
%       101 - constant J_AtC = x_AtC and fixed [CrP]c and [Cr]_c


%% Resetting key metabolic pools based on experimental observations
% --------------------------------------------
% Update CRtot and ATPobs_BL
CRtot = CT_cytowater_LVH;
ATPobs_BL = ATPBL_cellwater_LVH;

xo_LVH = xo_con;
load OptVar_LVH.mat;
xo_LVH(iPI_c) = OptVar_LVH(1);
xo_LVH(iATP_c) = OptVar_LVH(2);
xo_LVH(iPCr_c) = OptVar_LVH(3);
xo_LVH(iCr_c) = CT_cytowater_LVH - xo_LVH(iPCr_c);

% Run the simulation to steady states
iflag = 100;
[t,x] = ode15s(@Cell_dXdT,[0 2000],xo_LVH,options,param,x_AtC_LVH,iflag);

% Verify the results
xo_LVH= x(end,:);
CRtot_LVH_new = xo_LVH(iPCr_c)+xo_LVH(iCr_c); % per cyto water
ATPBL_cell_LVH_new = W_x*Rm_cell*xo_LVH(iATP_x) + W_i*Rm_cell*xo_LVH(iATP_i) + W_c*Rc_cell*xo_LVH(iATP_c) % per cell
CrPBL_cell_LVH_new = W_c*Rc_cell*xo_LVH(iPCr_c)
CrPBL_cell_LVH/ATPBL_cell_LVH
CrPBL_cell_LVH_new/ATPBL_cell_LVH_new


% --------------------------------------------
% Generating simulations
Np = 60; % Setting up the number of steady-state outputs
for i = 1:Np
  i
  x_AtC(i) =  (i-1)*(0.4e-3)/10; %(i-1)*(1.25e-3)/10 ; %(i-1)*(0.4e-3)/10 ; % mol s^{-1} (l cyto)^{-1}
  iflag = 0;
  [t,x] = ode15s(@Cell_dXdT,[0 2000],x(end,:),options,param,x_AtC(i),iflag);
  Flux = [];
  for j = 1:length(t)
    Flux(j,:) = Cell_Flux(x(j,:),param,x_AtC(i));
  end
  x_st(i,:) = x(end,:);
  Flux_st(i,:) = Cell_Flux(x(end,:),param,x_AtC(i));
  
  % Computing MRS-observed signals from local concentrations
  PIobs(i)  = W_c*Rc_cell*x(end,iPI_c) + W_x*Rm_cell*x(end,iPI_x) + W_i*Rm_cell*x(end,iPI_i); % per cell water
  ATPobs(i) = W_c*Rc_cell*x(end,iATP_c) + W_x*Rm_cell*x(end,iATP_x) + W_i*Rm_cell*x(end,iATP_i);
  PCRobs(i) = W_c*Rc_cell*x(end,iPCr_c);
end

Rc_t = 0.73078; % ratio volume cell/volume tissue
Rm_cell = 0.288; 
rho = 1.05; % tissue density grams per ml
Flux_C4 = Flux_st(:,6);
Flux_AtC = Flux_st(:,45);

% Converting the oxygen consumption rate from the Complex IV flux
MVO2_sim = (Flux_C4/2)*Rm_cell*Rc_t/(1000*rho)*60*1e6; % (umol O2) min-1 (g tissue)-1

% Computing the MRS-observed ratios
PCrATP_sim = PCRobs./ATPobs;
PCrATP_sim1 = PCRobs./ATPBL_cell_LVH;
PIPCr_sim = PIobs./PCRobs;
dG_AtC_sim = Flux_st(:,end);

ADP_c = x_st(:,iADP_c);
ATP_c = x_st(:,iATP_c);
PI_c = x_st(:,iPI_c);

%% save results of the moderate LVH hearts
save steady_states_LVH.mat;




